@@ -4,7 +4,7 @@
  * A class that implements the DB interface for Postgres
  * Note: This class uses ADODB and returns RecordSets.
  *
- * $Id: Postgres73.php,v 1.118 2004/06/04 05:26:35 chriskl Exp $
+ * $Id: Postgres73.php,v 1.140.2.2 2004/12/06 02:50:24 chriskl Exp $
  */
 
 // @@@ THOUGHT: What about inherits? ie. use of ONLY???
@@ -13,11 +13,6 @@ include_once('./classes/database/Postgres72.php');
 
 class Postgres73 extends Postgres72 {
 
-	var $uFields = array('uname' => 'usename', 'usuper' => 'usesuper', 'ucreatedb' => 'usecreatedb', 'uexpires' => 'valuntil', 'udefaults' => 'useconfig');
-
-	var $nspFields = array('nspname' => 'nspname', 'nspowner' => 'nspowner', 'nspcomment' => 'comment');
-	var $conFields = array('conname' => 'conname', 'conowner' => 'conowner');
-
 	// Store the current schema
 	var $_schema;
 
@@ -31,7 +26,7 @@ class Postgres73 extends Postgres72 {
 	// of objects.
 	var $privlist = array(
 		'table' => array('SELECT', 'INSERT', 'UPDATE', 'DELETE', 'RULE', 'REFERENCES', 'TRIGGER', 'ALL PRIVILEGES'),
-		'view' => array('SELECT', 'RULE', 'ALL PRIVILEGES'),
+		'view' => array('SELECT', 'INSERT', 'UPDATE', 'DELETE', 'RULE', 'REFERENCES', 'TRIGGER', 'ALL PRIVILEGES'),
 		'sequence' => array('SELECT', 'UPDATE', 'ALL PRIVILEGES'),
 		'database' => array('CREATE', 'TEMPORARY', 'ALL PRIVILEGES'),
 		'function' => array('EXECUTE', 'ALL PRIVILEGES'),
@@ -57,6 +52,13 @@ class Postgres73 extends Postgres72 {
 		$this->Postgres72($conn);
 	}
 
+	// Help functions
+	
+	function &getHelpPages() {
+		include_once('./help/PostgresDoc73.php');
+		return $this->help_page;
+	}
+
 	// Schema functions
 	
 	/**
@@ -65,7 +67,11 @@ class Postgres73 extends Postgres72 {
 	 * @return 0 success
 	 */
 	function setSchema($schema) {
-		$status = $this->setSearchPath(array($schema));
+		// Get the current schema search path, including 'pg_catalog'.
+		$search_path = $this->getSearchPath();
+		// Prepend $schema to search path
+		array_unshift($search_path, $schema);
+		$status = $this->setSearchPath($search_path);
 		if ($status == 0) {
 			$this->clean($schema);
 			$this->_schema = $schema;
@@ -83,13 +89,27 @@ class Postgres73 extends Postgres72 {
 	 */
 	function setSearchPath($paths) {
 		if (!is_array($paths)) return -1;
-		elseif (sizeof($paths) == 0) return -2;
+		elseif (sizeof($paths) == 0) return -2;		
+		elseif (sizeof($paths) == 1 && $paths[0] == '') {
+			// Need to handle empty paths in some cases
+			$paths[0] = 'pg_catalog';
+		}
 		$this->fieldArrayClean($paths);
 
-		$sql = 'SET SEARCH_PATH TO "' . implode('"', $paths) . '", pg_catalog';
+		$sql = 'SET SEARCH_PATH TO "' . implode('","', $paths) . '"';
 		
 		return $this->execute($sql);
 	}
+	
+	/**
+	 * Return the current schema search path
+	 * @return Array of schema names
+	 */
+	function getSearchPath() {
+		$sql = 'SELECT current_schemas(false) AS search_path';
+		
+		return $this->phpArray($this->selectField($sql, 'search_path'));
+	}
 
 	/**
 	 * Return all schemas in the current database
@@ -99,8 +119,8 @@ class Postgres73 extends Postgres72 {
 		global $conf;
 
 		if (!$conf['show_system']) $and = "AND nspname NOT LIKE 'pg\\\\_%'";
-		else $and = '';
-		$sql = "SELECT pn.nspname, pu.usename AS nspowner, pg_catalog.obj_description(pn.oid, 'pg_namespace') AS comment
+		else $and = "AND nspname !~ '^pg_t(emp_[0-9]+|oast)$'";
+		$sql = "SELECT pn.nspname, pu.usename AS nspowner, pg_catalog.obj_description(pn.oid, 'pg_namespace') AS nspcomment
                         FROM pg_catalog.pg_namespace pn, pg_catalog.pg_user pu
 			WHERE pn.nspowner = pu.usesysid
 			{$and} ORDER BY nspname";
@@ -115,7 +135,7 @@ class Postgres73 extends Postgres72 {
 	 */
 	function &getSchemaByName($schema) {
 		$this->clean($schema);
-		$sql = "SELECT nspname, nspowner,nspacl, pg_catalog.obj_description(pn.oid, 'pg_namespace') as comment
+		$sql = "SELECT nspname, nspowner, nspacl, pg_catalog.obj_description(pn.oid, 'pg_namespace') as nspcomment
                         FROM pg_catalog.pg_namespace pn
                         WHERE nspname='{$schema}'";
 		return $this->selectSet($sql);
@@ -125,7 +145,7 @@ class Postgres73 extends Postgres72 {
 	 * Creates a new schema.
 	 * @param $schemaname The name of the schema to create
 	 * @param $authorization (optional) The username to create the schema for.
-	 * @param $authorization (optional) If omitted, defaults to current user.
+	 * @param $comment (optional) If omitted, defaults to nothing
 	 * @return 0 success
 	 */
 	function createSchema($schemaname, $authorization = '', $comment = '') {
@@ -136,7 +156,6 @@ class Postgres73 extends Postgres72 {
 		$sql = "CREATE SCHEMA \"{$schemaname}\"";
 		if ($authorization != '') $sql .= " AUTHORIZATION \"{$authorization}\"";
 		
-		
 		$status = $this->beginTransaction();
 		if ($status != 0) return -1;
 
@@ -323,11 +342,10 @@ class Postgres73 extends Postgres72 {
 	function &getTable($table) {
 		$this->clean($table);
 		
-		$sql = "		
+		$sql = "
 			SELECT
-			  c.relname AS tablename,
-			  u.usename AS tableowner,
-			  pg_catalog.obj_description(c.oid, 'pg_class') AS tablecomment
+			  c.relname, u.usename AS relowner,
+			  pg_catalog.obj_description(c.oid, 'pg_class') AS relcomment
 			FROM pg_catalog.pg_class c
 			     LEFT JOIN pg_catalog.pg_user u ON u.usesysid = c.relowner
 			     LEFT JOIN pg_catalog.pg_namespace n ON n.oid = c.relnamespace
@@ -346,19 +364,20 @@ class Postgres73 extends Postgres72 {
 	function &getTables($all = false) {
 		if ($all) {
 			// Exclude pg_catalog and information_schema tables
-			$sql = "SELECT schemaname, tablename, tableowner
-                                FROM pg_catalog.pg_tables 
-				WHERE schemaname NOT IN ('pg_catalog', 'information_schema', 'pg_toast')
-				ORDER BY schemaname, tablename";
+			$sql = "SELECT schemaname AS nspname, tablename AS relname, tableowner AS relowner
+					FROM pg_catalog.pg_tables 
+					WHERE schemaname NOT IN ('pg_catalog', 'information_schema', 'pg_toast')
+					ORDER BY schemaname, tablename";
 		} else {
-			$sql = "SELECT c.relname AS tablename, pg_catalog.pg_get_userbyid(c.relowner) AS tableowner, 
-						pg_catalog.obj_description(c.oid, 'pg_class') AS tablecomment
+			$sql = "SELECT c.relname, pg_catalog.pg_get_userbyid(c.relowner) AS relowner, 
+						pg_catalog.obj_description(c.oid, 'pg_class') AS relcomment,
+						reltuples::integer
 					FROM pg_catalog.pg_class c
 					LEFT JOIN pg_catalog.pg_namespace n ON n.oid = c.relnamespace
 					WHERE c.relkind = 'r'
 					AND nspname='{$this->_schema}'
 					ORDER BY c.relname";
-		}		
+		}
 
 		return $this->selectSet($sql);
 	}
@@ -478,7 +497,7 @@ class Postgres73 extends Postgres72 {
 		
 		$sql = "
 			SELECT 
-				pn.nspname AS schemaname, relname
+				pn.nspname, relname
 			FROM
 				pg_catalog.pg_class pc, pg_catalog.pg_inherits pi, pg_catalog.pg_namespace pn
 			WHERE
@@ -504,7 +523,7 @@ class Postgres73 extends Postgres72 {
 		
 		$sql = "
 			SELECT 
-				pn.nspname AS schemaname, relname
+				pn.nspname, relname
 			FROM
 				pg_catalog.pg_class pc, pg_catalog.pg_inherits pi, pg_catalog.pg_namespace pn
 			WHERE
@@ -524,10 +543,10 @@ class Postgres73 extends Postgres72 {
 	 * @return All views
 	 */
 	function getViews() {
-		$sql = "SELECT c.relname AS viewname, pg_catalog.pg_get_userbyid(c.relowner) AS viewowner, 
-                          pg_catalog.obj_description(c.oid, 'pg_class') AS comment
+		$sql = "SELECT c.relname, pg_catalog.pg_get_userbyid(c.relowner) AS relowner, 
+                          pg_catalog.obj_description(c.oid, 'pg_class') AS relcomment
                         FROM pg_catalog.pg_class c LEFT JOIN pg_catalog.pg_namespace n ON (n.oid = c.relnamespace)
-                        WHERE (n.nspname='{$this->_schema}') AND (c.relkind = 'v'::\"char\")  ORDER BY viewname";
+                        WHERE (n.nspname='{$this->_schema}') AND (c.relkind = 'v'::\"char\")  ORDER BY relname";
 
 		return $this->selectSet($sql);
 	}
@@ -540,8 +559,8 @@ class Postgres73 extends Postgres72 {
 	function &getView($view) {
 		$this->clean($view);
 
-		$sql = "SELECT c.relname AS viewname, pg_catalog.pg_get_userbyid(c.relowner) AS viewowner, 
-                          pg_catalog.pg_get_viewdef(c.oid) AS definition, pg_catalog.obj_description(c.oid, 'pg_class') AS comment
+		$sql = "SELECT c.relname, pg_catalog.pg_get_userbyid(c.relowner) AS relowner, 
+                          pg_catalog.pg_get_viewdef(c.oid) AS vwdefinition, pg_catalog.obj_description(c.oid, 'pg_class') AS relcomment
                         FROM pg_catalog.pg_class c LEFT JOIN pg_catalog.pg_namespace n ON (n.oid = c.relnamespace)
                         WHERE (c.relname = '$view')
                         AND n.nspname='{$this->_schema}'";
@@ -569,10 +588,10 @@ class Postgres73 extends Postgres72 {
 	 * @return A recordset
 	 */
 	function &getSequences() {
-		$sql = "SELECT c.relname, u.usename, pg_catalog.obj_description(c.oid, 'pg_class') AS seqcomment
+		$sql = "SELECT c.relname AS seqname, u.usename AS seqowner, pg_catalog.obj_description(c.oid, 'pg_class') AS seqcomment
 			FROM pg_catalog.pg_class c, pg_catalog.pg_user u, pg_catalog.pg_namespace n
 			WHERE c.relowner=u.usesysid AND c.relnamespace=n.oid
-			AND c.relkind = 'S' AND n.nspname='{$this->_schema}' ORDER BY relname";
+			AND c.relkind = 'S' AND n.nspname='{$this->_schema}' ORDER BY seqname";
 			
 		return $this->selectSet( $sql );
 	}
@@ -585,7 +604,7 @@ class Postgres73 extends Postgres72 {
 	function &getSequence($sequence) {
 		$this->fieldClean($sequence);
 	
-		$sql = "SELECT sequence_name AS relname, *, pg_catalog.obj_description(s.tableoid, 'pg_class') AS seqcomment FROM \"{$sequence}\" AS s"; 
+		$sql = "SELECT sequence_name AS seqname, *, pg_catalog.obj_description(s.tableoid, 'pg_class') AS seqcomment FROM \"{$sequence}\" AS s"; 
 		
 		return $this->selectSet( $sql );
 	}
@@ -598,17 +617,11 @@ class Postgres73 extends Postgres72 {
 	function &getIndexes($table = '') {
 		$this->clean($table);
 		
-		/* This select excludes any indexes that are just base indexes for constraints. */
-		$sql = "SELECT c2.relname, i.indisprimary, i.indisunique, i.indisclustered,
-			pg_catalog.pg_get_indexdef(i.indexrelid) as pg_get_indexdef
+		$sql = "SELECT c2.relname AS indname, i.indisprimary, i.indisunique, i.indisclustered,
+			pg_catalog.pg_get_indexdef(i.indexrelid) AS inddef
 			FROM pg_catalog.pg_class c, pg_catalog.pg_class c2, pg_catalog.pg_index i
 			WHERE c.relname = '{$table}' AND pg_catalog.pg_table_is_visible(c.oid) 
 			AND c.oid = i.indrelid AND i.indexrelid = c2.oid
-			AND NOT EXISTS (
-				SELECT 1 FROM pg_catalog.pg_depend d JOIN pg_catalog.pg_constraint c
-				ON (d.refclassid = c.tableoid AND d.refobjid = c.oid)
-				WHERE d.classid = c2.tableoid AND d.objid = c2.oid AND d.deptype = 'i' AND c.contype IN ('u', 'p')
-			)
 			ORDER BY c2.relname";
 
 		return $this->selectSet($sql);
@@ -701,19 +714,21 @@ class Postgres73 extends Postgres72 {
 
 		$sql = "SELECT
 				{$distinct}
-				p.oid,
+				p.oid AS prooid,
 				p.proname,
 				p.proretset,
-				pg_catalog.format_type(p.prorettype, NULL) AS return_type,
-				pg_catalog.oidvectortypes(p.proargtypes) AS arguments,
-				pg_catalog.obj_description(p.oid, 'pg_proc') AS funccomment
+				pg_catalog.format_type(p.prorettype, NULL) AS proresult,
+				pg_catalog.oidvectortypes(p.proargtypes) AS proarguments,
+				pl.lanname AS prolanguage,
+				pg_catalog.obj_description(p.oid, 'pg_proc') AS procomment
 			FROM pg_catalog.pg_proc p
-			LEFT JOIN pg_catalog.pg_namespace n ON n.oid = p.pronamespace
+				INNER JOIN pg_catalog.pg_namespace n ON n.oid = p.pronamespace
+				INNER JOIN pg_catalog.pg_language pl ON pl.oid = p.prolang
 			WHERE p.prorettype <> 'pg_catalog.cstring'::pg_catalog.regtype
-			AND p.proargtypes[0] <> 'pg_catalog.cstring'::pg_catalog.regtype
-			AND NOT p.proisagg
-			AND {$where}
-			ORDER BY p.proname, return_type
+				AND p.proargtypes[0] <> 'pg_catalog.cstring'::pg_catalog.regtype
+				AND NOT p.proisagg
+				AND {$where}
+			ORDER BY p.proname, proresult
 			";
 
 		return $this->selectSet($sql);
@@ -728,18 +743,18 @@ class Postgres73 extends Postgres72 {
 		$this->clean($function_oid);
 		
 		$sql = "SELECT 
-					pc.oid,
+					pc.oid AS prooid,
 					proname,
-					lanname as language,
-					format_type(prorettype, NULL) as return_type,
-					prosrc as source,
-					probin as binary,
+					lanname as prolanguage,
+					pg_catalog.format_type(prorettype, NULL) as proresult,
+					prosrc,
+					probin,
 					proretset,
 					proisstrict,
 					provolatile,
 					prosecdef,
-					oidvectortypes(pc.proargtypes) AS arguments,
-					pg_catalog.obj_description(pc.oid, 'pg_proc') AS funccomment
+					pg_catalog.oidvectortypes(pc.proargtypes) AS proarguments,
+					pg_catalog.obj_description(pc.oid, 'pg_proc') AS procomment
 				FROM
 					pg_catalog.pg_proc pc, pg_catalog.pg_language pl
 				WHERE 
@@ -807,7 +822,6 @@ class Postgres73 extends Postgres72 {
 	function createFunction($funcname, $args, $returns, $definition, $language, $flags, $setof, $replace = false) {
 		$this->fieldClean($funcname);
 		$this->clean($args);
-		$this->clean($definition);
 		$this->clean($language);
 		$this->arrayClean($flags);
 
@@ -821,9 +835,19 @@ class Postgres73 extends Postgres72 {
 		// For some reason, the returns field cannot have quotes...
 		$sql .= ") RETURNS ";
 		if ($setof) $sql .= "SETOF ";
-		$sql .= "{$returns} AS '\n";
-		$sql .= $definition;
-		$sql .= "\n'";
+		$sql .= "{$returns} AS ";
+		
+		if (is_array($definition)) {
+			$this->arrayClean($definition);
+			$sql .= "'" . $definition[0] . "'";
+			if ($definition[1]) {
+				$sql .= ",'" . $definition[1] . "'";
+			}
+		} else {
+			$this->clean($definition);
+			$sql .= "'" . $definition . "'";
+		}
+		
 		$sql .= " LANGUAGE \"{$language}\"";
 		
 		// Add flags
@@ -841,10 +865,11 @@ class Postgres73 extends Postgres72 {
 	/**
 	 * Returns a list of all types in the database
 	 * @param $all If true, will find all available functions, if false just those in search path
-	 * @param $tabletypes If true, will include table types, false will not.
+	 * @param $tabletypes If true, will include table types
+	 * @param $domains If true, will include domains
 	 * @return A recordet
 	 */
-	function &getTypes($all = false, $tabletypes = false) {
+	function &getTypes($all = false, $tabletypes = false, $domains = false) {
 		if ($all)
 			$where = 'pg_catalog.pg_type_is_visible(t.oid)';
 		else
@@ -852,29 +877,127 @@ class Postgres73 extends Postgres72 {
 		// Never show system table types
 		$where2 = "AND c.relnamespace NOT IN (SELECT oid FROM pg_catalog.pg_namespace WHERE nspname LIKE 'pg\\\\_%')";
 
+		// Create type filter
+		$tqry = "'c'";
 		if ($tabletypes)
-			$tqry = "'c', 'r', 'v'";
-		else
-			$tqry = "'c'";
+			$tqry .= ", 'r', 'v'";
+
+		// Create domain filter
+		if (!$domains)
+			$where .= " AND t.typtype != 'd'";
 			
 		$sql = "SELECT
 				t.typname AS basename,
 				pg_catalog.format_type(t.oid, NULL) AS typname,
 				pu.usename AS typowner,
+				t.typtype,
 				pg_catalog.obj_description(t.oid, 'pg_type') AS typcomment
 			FROM (pg_catalog.pg_type t
 				LEFT JOIN pg_catalog.pg_namespace n ON n.oid = t.typnamespace)
 				LEFT JOIN pg_catalog.pg_user pu ON t.typowner = pu.usesysid
 			WHERE (t.typrelid = 0 OR (SELECT c.relkind IN ({$tqry}) FROM pg_catalog.pg_class c WHERE c.oid = t.typrelid {$where2}))	 
 			AND t.typname !~ '^_'
-			AND {$where}
-			AND t.typtype != 'd'
+			AND {$where}			
 			ORDER BY typname
 		";
 
 		return $this->selectSet($sql);
 	}
-	
+
+	/**
+	 * Creates a new composite type in the database
+	 * @param $name The name of the type
+	 * @param $fields The number of fields
+	 * @param $field An array of field names
+	 * @param $type An array of field types
+	 * @param $array An array of '' or '[]' for each type if it's an array or not
+	 * @param $length An array of field lengths
+	 * @param $colcomment An array of comments
+	 * @param $typcomment Type comment
+	 * @return 0 success
+	 * @return -1 no fields supplied
+	 */
+	function createCompositeType($name, $fields, $field, $type, $array, $length, $colcomment, $typcomment) {
+		$this->fieldClean($name);
+		$this->clean($typcomment);
+
+		$status = $this->beginTransaction();
+		if ($status != 0) return -1;
+
+		$found = false;
+		$first = true;
+		$comment_sql = ''; // Accumulate comments for the columns
+		$sql = "CREATE TYPE \"{$name}\" AS (";
+		for ($i = 0; $i < $fields; $i++) {
+			$this->fieldClean($field[$i]);
+			$this->clean($type[$i]);
+			$this->clean($length[$i]);
+			$this->clean($colcomment[$i]);
+
+			// Skip blank columns - for user convenience
+			if ($field[$i] == '' || $type[$i] == '') continue;
+			// If not the first column, add a comma
+			if (!$first) $sql .= ", ";
+			else $first = false;
+			
+			switch ($type[$i]) {
+				// Have to account for weird placing of length for with/without
+				// time zone types
+				case 'timestamp with time zone':
+				case 'timestamp without time zone':
+					$qual = substr($type[$i], 9);
+					$sql .= "\"{$field[$i]}\" timestamp";
+					if ($length[$i] != '') $sql .= "({$length[$i]})";
+					$sql .= $qual;
+					break;
+				case 'time with time zone':
+				case 'time without time zone':
+					$qual = substr($type[$i], 4);
+					$sql .= "\"{$field[$i]}\" time";
+					if ($length[$i] != '') $sql .= "({$length[$i]})";
+					$sql .= $qual;
+					break;
+				default:
+					$sql .= "\"{$field[$i]}\" {$type[$i]}";
+					if ($length[$i] != '') $sql .= "({$length[$i]})";
+			}
+			// Add array qualifier if necessary
+			if ($array[$i] == '[]') $sql .= '[]';
+
+			if ($colcomment[$i] != '') $comment_sql .= "COMMENT ON COLUMN \"{$name}\".\"{$field[$i]}\" IS '{$colcomment[$i]}';\n";
+
+			$found = true;
+		}
+		
+		if (!$found) return -1;
+		
+		$sql .= ")";
+				
+		$status = $this->execute($sql);
+		if ($status) {
+			$this->rollbackTransaction();
+			return -1;
+		}
+
+		if ($typcomment != '') {
+			$status = $this->setComment('TYPE', $name, '', $typcomment, true);
+			if ($status) {
+				$this->rollbackTransaction();
+				return -1;
+			}
+		}
+
+		if ($comment_sql != '') {
+			$status = $this->execute($comment_sql);
+			if ($status) {
+				$this->rollbackTransaction();
+				return -1;
+			}
+		}
+		return $this->endTransaction();
+		
+	}
+		
 	// Rule functions
 	
 	/**
@@ -943,14 +1066,15 @@ class Postgres73 extends Postgres72 {
 	 function &getLinkingKeys($tables) {
 		if (!is_array($tables)) return -1;
 
- 		$tables_list = "'{$tables[0]['tablename']}'";
- 		$schema_list = "'{$tables[0]['schemaname']}'";
- 		$schema_tables_list = "'{$tables[0]['schemaname']}.{$tables[0]['tablename']}'";
- 		for ($i = 1; $i < sizeof($tables); $i++) {
- 			$tables_list .= ", '{$tables[$i]['tablename']}'";
- 			$schema_list .= ", '{$tables[$i]['schemaname']}'";
- 			$schema_tables_list .= ", '{$tables[$i]['schemaname']}.{$tables[$i]['tablename']}'";
- 		}
+		
+		$tables_list = "'{$tables[0]['schemaname']}'";
+		$schema_list = "'{$tables[0]['tablename']}'";
+		$schema_tables_list = "'{$tables[0]['schemaname']}.{$tables[0]['tablename']}'";
+		for ($i = 1; $i < sizeof($tables); $i++) {
+			$tables_list .= ", '{$tables[$i]['tablename']}'";
+			$schema_list .= ", '{$tables[$i]['schemaname']}'";
+			$schema_tables_list .= ", '{$tables[$i]['schemaname']}.{$tables[$i]['tablename']}'";
+		}
 		$maxDimension = 1;
 
 		$sql = "
@@ -1013,39 +1137,6 @@ class Postgres73 extends Postgres72 {
 		return $this->selectSet($sql);
 	 }
 
-	/**
-	 * A helper function for getConstraints that translates
-	 * an array of attribute numbers to an array of field names.
-	 * @param $table The name of the table
-	 * @param $columsn An array of column ids
-	 * @return An array of column names
-	 */
-	function &getKeys($table, $colnums) {
-		$this->clean($table);
-		$this->arrayClean($colnums);
-
-		$sql = "SELECT attnum, attname FROM pg_catalog.pg_attribute
-			WHERE attnum IN ('" . join("','", $colnums) . "')
-			AND attrelid = (SELECT oid FROM pg_catalog.pg_class WHERE relname='{$table}'
-					AND relnamespace = (SELECT oid FROM pg_catalog.pg_namespace
-					WHERE nspname='{$this->_schema}'))";
-
-		$rs = $this->selectSet($sql);
-
-		$temp = array();
-		while (!$rs->EOF) {
-			$temp[$rs->f['attnum']] = $rs->f['attname'];
-			$rs->moveNext();
-		}
-
-		$atts = array();
-		foreach ($colnums as $v) {
-			$atts[] = '"' . $temp[$v] . '"';
-		}
-		
-		return $atts;
-	}
-
 	/**
 	 * Returns a list of all constraints on a table
 	 * @param $table The table to find rules for
@@ -1195,6 +1286,9 @@ class Postgres73 extends Postgres72 {
 			case 'schema':
 				$sql = "SELECT nspacl AS acl FROM pg_catalog.pg_namespace WHERE nspname='{$object}'";
 				break;
+			case 'tablespace':
+				$sql = "SELECT spcacl AS acl FROM pg_catalog.pg_tablespace WHERE spcname='{$object}'";
+				break;
 			default:
 				return -1;
 		}
@@ -1326,15 +1420,17 @@ class Postgres73 extends Postgres72 {
 	/**
 	 * Searches all system catalogs to find objects that match a certain name.
 	 * @param $term The search term
+	 * @param $filter The object type to restrict to ('' means no restriction)
 	 * @return A recordset
 	 */
-	function findObject($term) {
+	function findObject($term, $filter) {
 		global $conf;
 
 		// Escape search term for ILIKE match
 		$term = str_replace('_', '\\_', $term);
 		$term = str_replace('%', '\\%', $term);
 		$this->clean($term);
+		$this->clean($filter);
 
 		// Exclude system relations if necessary
 		if (!$conf['show_system']) {
@@ -1348,7 +1444,13 @@ class Postgres73 extends Postgres72 {
 			$lan_where = '';
 		}
 		
-		$sql = "
+		// Apply outer filter
+		$sql = '';
+		if ($filter != '') {
+			$sql = "SELECT * FROM (";
+		}
+		
+		$sql .= "
 			SELECT 'SCHEMA' AS type, oid, NULL AS schemaname, NULL AS relname, nspname AS name 
 				FROM pg_catalog.pg_namespace pn WHERE nspname ILIKE '%{$term}%' {$where}
 			UNION ALL
@@ -1360,7 +1462,7 @@ class Postgres73 extends Postgres72 {
 				pg_catalog.pg_attribute pa WHERE pc.relnamespace=pn.oid AND pc.oid=pa.attrelid 
 				AND pa.attname ILIKE '%{$term}%' AND pa.attnum > 0 AND NOT pa.attisdropped AND pc.relkind IN ('r', 'v') {$where}
 			UNION ALL
-			SELECT 'FUNCTION', pp.oid, pn.nspname, NULL, pp.proname FROM pg_catalog.pg_proc pp, pg_catalog.pg_namespace pn 
+			SELECT 'FUNCTION', pp.oid, pn.nspname, NULL, pp.proname || '(' || pg_catalog.oidvectortypes(pp.proargtypes) || ')' FROM pg_catalog.pg_proc pp, pg_catalog.pg_namespace pn 
 				WHERE pp.pronamespace=pn.oid AND NOT pp.proisagg AND pp.proname ILIKE '%{$term}%' {$where}
 			UNION ALL
 			SELECT 'INDEX', NULL, pn.nspname, pc.relname, pc2.relname FROM pg_catalog.pg_class pc, pg_catalog.pg_namespace pn,
@@ -1445,8 +1547,13 @@ class Postgres73 extends Postgres72 {
 			";
 		}
 
+		if ($filter != '') {
+			// We use like to make RULE, CONSTRAINT and COLUMN searches work
+			$sql .= ") AS sub WHERE type LIKE '{$filter}%' ";
+		}
+
 		$sql .= "ORDER BY type, schemaname, relname, name";
-			
+
 		return $this->selectSet($sql);
 	}	
 
@@ -1687,10 +1794,10 @@ class Postgres73 extends Postgres72 {
 	function hasUserSessionDefaults() { return true; }
 	function hasVariables() { return true; }
 	function hasFullExplain() { return true; }
-	function hasFunctionRename() { return false; }
 	function hasForeignKeysInfo() { return true; }
 	function hasViewColumnRename() { return true; }
-
+	function hasUserAndDbVariables() { return true; }
+	function hasCompositeTypes() { return true; }	
 }
 
 ?>
