@@ -3,9 +3,11 @@
 	 * Does an export of a database or a table (via pg_dump)
 	 * to the screen or as a download.
 	 *
-	 * $Id: dbexport.php,v 1.14.2.1 2004/12/06 03:07:17 chriskl Exp $
+	 * $Id: dbexport.php,v 1.14.2.3 2005/02/09 11:31:49 chriskl Exp $
 	 */
 
+      // Prevent timeouts on large exports
+      set_time_limit(0);
 	// Include application functions
 	$_no_output = true;
 	include_once('./libraries/lib.inc.php');
@@ -69,7 +71,7 @@
 			
 			// Obtain the pg_dump version number
 			$version = array();
-			preg_match("/(\d+(?:\.\d+)?)(?:\.\d+)?$/", exec($exe . " --version"), $version);
+			preg_match("/(\d+(?:\.\d+)?)(?:\.\d+)?.*$/", exec($exe . " --version"), $version);
 			
 			// If we are 7.4 or higher, assume they are using 7.4 pg_dump and
 			// set dump schema as well.  Also, mixed case dumping has been fixed
