@@ -4,7 +4,7 @@
 	 * Italian language file, based on the english language file for phpPgAdmin.
 	 * Nicola Soranzo [nsoranzo@tiscali.it]
          *
-	 * $Id: italian.php,v 1.26 2004/05/26 11:27:00 soranzo Exp $
+	 * $Id: italian.php,v 1.33.2.1 2004/12/02 02:28:54 chriskl Exp $
 	 */
 
 	// Language and character set - Lingua e set di caratteri
@@ -12,6 +12,7 @@
 	$lang['appcharset'] = 'ISO-8859-1';
 	$lang['applocale'] = 'it_IT';
 	$lang['appdbencoding'] = 'LATIN1';
+	$lang['applangdir'] = 'ltr';
 
 	// Welcome - Benvenuto
 	$lang['strintro'] = 'Benvenuto in phpPgAdmin.';
@@ -65,6 +66,7 @@
 	$lang['strtrue'] = 'TRUE';
 	$lang['strfalse'] = 'FALSE';
 	$lang['stredit'] = 'Modifica';
+	$lang['strcolumn'] = 'Colonna';
 	$lang['strcolumns'] = 'Colonne';
 	$lang['strrows'] = 'riga(ghe)';
 	$lang['strrowsaff'] = 'riga(ghe) interessata(e).';
@@ -100,6 +102,7 @@
 	$lang['strconfirm'] = 'Conferma';
 	$lang['strexpression'] = 'Espressione';
 	$lang['strellipsis'] = '...';
+	$lang['strseparator'] = ': ';
 	$lang['strexpand'] = 'Espandi';
 	$lang['strcollapse'] = 'Raccogli';
 	$lang['strexplain'] = 'Explain';
@@ -125,9 +128,11 @@
 	$lang['strfileimported'] = 'File importato.';
 
 	// Error handling - Gestione degli errori
-	$lang['strnoframes'] = 'Devi usare un browser che supporti i frame per usare questa applicazione.';
-	$lang['strbadconfig'] = 'Il file config.inc.php &egrave; obsoleto. Devi rigenerarlo utilizzando il nuovo file config.inc.php-dist .';
-	$lang['strnotloaded'] = 'La tua installazione di PHP non supporta PostgreSQL. Devi ricompilare PHP usando l\'opzione di configurazione --with-pgsql .';
+	$lang['strnoframes'] = 'Per usare questa applicazione &egrave; necessario usare un browser che supporti i frame.';
+	$lang['strbadconfig'] = 'Il file config.inc.php &egrave; obsoleto. &Egrave; necessario rigenerarlo utilizzando il nuovo file config.inc.php-dist .';
+	$lang['strnotloaded'] = 'La tua installazione di PHP non supporta PostgreSQL. &Egrave; necessario ricompilare PHP usando l\'opzione di configurazione --with-pgsql .';
+	$lang['strphpversionnotsupported'] = 'Versione di PHP non supportata. &Egrave; necessario aggiornarlo alla versione %s o successiva.';
+	$lang['strpostgresqlversionnotsupported'] = 'Versione di PostgreSQL non supportata. &Egrave; necessario aggiornarlo alla versione %s o successiva.';
 	$lang['strbadschema'] = 'Schema specificato non valido.';
 	$lang['strbadencoding'] = 'Impostazione della codifica del client nel database fallito.';
 	$lang['strsqlerror'] = 'Errore SQL:';
@@ -144,14 +149,14 @@
         // Tables - Tabelle
 	$lang['strtable'] = 'Tabella';
 	$lang['strtables'] = 'Tabelle';
-	$lang['strshowalltables'] = 'Mostra tutte le Tabelle';
+	$lang['strshowalltables'] = 'Mostra tutte le tabelle';
 	$lang['strnotables'] = 'Nessuna tabella trovata.';
 	$lang['strnotable'] = 'Tabella non trovata.';
 	$lang['strcreatetable'] = 'Crea tabella';
 	$lang['strtablename'] = 'Nome tabella';
 	$lang['strtableneedsname'] = '&Egrave; necessario specificare un nome per la tabella.';
 	$lang['strtableneedsfield'] = '&Egrave; necessario specificare almeno un campo.';
-	$lang['strtableneedscols'] = 'Le tabelle richiedono un numero di colonne valido.';
+	$lang['strtableneedscols'] = '&Egrave; necessario specificare un numero di colonne valido.';
 	$lang['strtablecreated'] = 'Tabella creata.';
 	$lang['strtablecreatedbad'] = 'Creazione della tabella fallita.';
 	$lang['strconfdroptable'] = 'Sei sicuro di voler eliminare la tabella &quot;%s&quot;?';
@@ -170,11 +175,9 @@
 	$lang['strconfdeleterow'] = 'Sei sicuro di voler cancellare questa riga?';
 	$lang['strrowdeleted'] = 'Riga cancellata.';
 	$lang['strrowdeletedbad'] = 'Cancellazione della riga fallita.';
-	$lang['strsaveandrepeat'] = 'Salva e ripeti';
-	$lang['strfield'] = 'Campo';
-	$lang['strfields'] = 'Campi';
-	$lang['strnumfields'] = 'Numero di campi';
-	$lang['strfieldneedsname'] = '&Egrave; necessario specificare un nome per i campi.';
+	$lang['strinsertandrepeat'] = 'Inserisci e ripeti';
+	$lang['strnumcols'] = 'Numero di colonne';
+	$lang['strcolneedsname'] = '&Egrave; necessario specificare un nome per la colonna';
 	$lang['strselectallfields'] = 'Seleziona tutti i campi';
         $lang['strselectneedscol'] = '&Egrave; necessario scegliere almeno una colonna.';
 	$lang['strselectunary'] = 'Gli operatori unari non possono avere un valore.';
@@ -195,6 +198,8 @@
 	$lang['strstructureanddata'] = 'Struttura e dati';
 	$lang['strtabbed'] = 'Tabulato';
 	$lang['strauto'] = 'Auto';
+	$lang['strconfvacuumtable'] = 'Sei sicuro di voler effettuare il vacuum su &quot;%s&quot;?';
+	$lang['strestimatedrowcount'] = 'Numero stimato di righe';
 
 	// Users - Utenti
 	$lang['struser'] = 'Utente';
@@ -254,7 +259,6 @@
 	$lang['strgranted'] = 'Privilegi concessi.';
 	$lang['strgrantfailed'] = 'Concessione dei privilegi fallita.';
 	$lang['strgrantbad'] = '&Egrave; necessario specificare almeno un utente o gruppo ed almeno un privilegio.';
-	$lang['stralterprivs'] = 'Modifica privilegi';
 	$lang['strgrantor'] = 'Grantor'; // ???
 	$lang['strasterisk'] = '*';
 
@@ -283,6 +287,9 @@
 	$lang['strfull'] = 'Completo';
 	$lang['strfreeze'] = 'Freeze';
 	$lang['strforce'] = 'Forza';
+	$lang['strsignalsent'] = 'Segnale inviato.';
+	$lang['strsignalsentbad'] = 'Invio del segnale fallito.';
+	$lang['strallobjects'] = 'Tutti gli oggetti';
 
 	// Views - Viste
 	$lang['strview'] = 'Vista';
@@ -374,6 +381,7 @@
 	$lang['strruledroppedbad'] = 'Eliminazione della regola fallita.';
 
 	// Constraints - Vincoli
+	$lang['strconstraint'] = 'Vincolo';
 	$lang['strconstraints'] = 'Vincoli';
 	$lang['strshowallconstraints'] = 'Mostra tutti i vincoli';
 	$lang['strnoconstraints'] = 'Nessun vincolo trovato.';
@@ -411,7 +419,9 @@
 	$lang['strshowallfunctions'] = 'Mostra tutte le funzioni';
 	$lang['strnofunction'] = 'Funzione non trovata.';
 	$lang['strnofunctions'] = 'Nessuna funzione trovata.';
-	$lang['strcreatefunction'] = 'Crea funzione';
+	$lang['strcreateplfunction'] = 'Crea funzione SQL/PL';
+	$lang['strcreateinternalfunction'] = 'Crea funzione internal';
+	$lang['strcreatecfunction'] = 'Crea funzione C';
 	$lang['strfunctionname'] = 'Nome della funzione';
 	$lang['strreturns'] = 'Restituisce';
 	$lang['strarguments'] = 'Argomenti';
@@ -425,6 +435,8 @@
         $lang['strfunctiondroppedbad'] = 'Eliminazione della funzione fallita.';
         $lang['strfunctionupdated'] = 'Funzione aggiornata.';
         $lang['strfunctionupdatedbad'] = 'Aggiornamento della funzione fallito.';
+	$lang['strobjectfile'] = 'File oggetto';
+	$lang['strlinksymbol'] = 'Simbolo di collegamento';
 
         // Triggers - Trigger
         $lang['strtrigger'] = 'Trigger';
@@ -450,6 +462,9 @@
         $lang['strnotype'] = 'Tipo non trovato.';
         $lang['strnotypes'] = 'Nessun tipo trovato.';
         $lang['strcreatetype'] = 'Crea Tipo';
+	$lang['strcreatecomptype'] = 'Crea tipo composto';
+	$lang['strtypeneedsfield'] = '&Egrave; necessario specificare almeno un campo.';
+	$lang['strtypeneedscols'] = '&Egrave; necessario specificare un numero di campi valido.';	
         $lang['strtypename'] = 'Nome Tipo';
         $lang['strinputfn'] = 'Funzione di input';
         $lang['stroutputfn'] = 'Funzione di output';
@@ -458,6 +473,8 @@
         $lang['strelement'] = 'Elemento';
         $lang['strdelimiter'] = 'Delimitatore';
         $lang['strstorage'] = 'Memorizzazione';
+	$lang['strfield'] = 'Campo';
+	$lang['strnumfields'] = 'Numero di campi';
         $lang['strtypeneedsname'] = '&Egrave; necessario specificare un nome per il tipo.';
         $lang['strtypeneedslen'] = '&Egrave; necessario specificare una lunghezza per il tipo.';
         $lang['strtypecreated'] = 'Tipo creato';
@@ -465,6 +482,10 @@
         $lang['strconfdroptype'] = 'Sei sicuro di voler eliminare il tipo &quot;%s&quot;?';
         $lang['strtypedropped'] = 'Tipo eliminato.';
         $lang['strtypedroppedbad'] = 'Eliminazione del tipo fallita.';
+	$lang['strflavor'] = 'Variet&agrave;';
+	$lang['strbasetype'] = 'Base';
+	$lang['strcompositetype'] = 'Composto';
+	$lang['strpseudotype'] = 'Pseudo-tipo';
 
         // Schemas - Schemi
         $lang['strschema'] = 'Schema';
@@ -482,6 +503,7 @@
         $lang['strschemadroppedbad'] = 'Eliminazione dello schema fallita.';
 	$lang['strschemaaltered'] = 'Schema modificato.';
 	$lang['strschemaalteredbad'] = 'Modifica dello schema fallita.';
+	$lang['strsearchpath'] = 'Ordine di ricerca dello schema';
 
         // Reports - Report
         $lang['strreport'] = 'Report';
@@ -591,9 +613,27 @@
 	$lang['strdisk'] = 'Disco';
 	$lang['strrows2'] = 'Righe';
 
+	// Tablespaces - Tablespace
+	$lang['strtablespace'] = 'Tablespace';
+	$lang['strtablespaces'] = 'Tablespace';
+	$lang['strshowalltablespaces'] = 'Mostra tutti i tablespace';
+	$lang['strnotablespaces'] = 'Nessun tablespace trovato.';
+	$lang['strcreatetablespace'] = 'Crea tablespace';
+	$lang['strlocation'] = 'Directory';
+	$lang['strtablespaceneedsname'] = '&Egrave; necessario specificare un nome per il tablespace.';
+	$lang['strtablespaceneedsloc'] = '&Egrave; necessario specificare una directory in cui creare il tablespace.';
+	$lang['strtablespacecreated'] = 'Tablespace creato.';
+	$lang['strtablespacecreatedbad'] = 'Crezione del tablespace fallita.';
+	$lang['strconfdroptablespace'] = 'Sei sicuro di voler eliminare il tablespace &quot;%s&quot;?';
+	$lang['strtablespacedropped'] = 'Tablespace eliminato.';
+	$lang['strtablespacedroppedbad'] = 'Eliminazione del tablespace fallita.';
+	$lang['strtablespacealtered'] = 'Tablespace modificato.';
+	$lang['strtablespacealteredbad'] = 'Modifica del tablespace fallita.';
+
 	// Miscellaneous - Varie
-        $lang['strtopbar'] = '%s in esecuzione su %s:%s -- Sei entrato come utente &quot;%s&quot;, %s';
+        $lang['strtopbar'] = '%s in esecuzione su %s:%s -- Utente &quot;%s&quot; connesso il %s';
         $lang['strtimefmt'] = 'j M Y - g:iA';
 	$lang['strhelp'] = 'Aiuto';
+	$lang['strhelpicon'] = '?';
 
 ?>
