@@ -4,7 +4,7 @@
 	 * Spanish language file for phpPgAdmin.
 	 * @maintainer Martn Marqus (martin@bugs.unl.edu.ar)
 	 *
-	 * $Id: spanish.php,v 1.23 2004/05/18 00:45:29 soranzo Exp $
+	 * $Id: spanish.php,v 1.27 2004/11/10 01:37:43 chriskl Exp $
 	 */
 
 	// Language and character set
@@ -12,6 +12,7 @@
 	$lang['appcharset'] = 'ISO-8859-1';
 	$lang['applocale'] = 'es_ES';
   	$lang['appdbencoding'] = 'LATIN1';
+	$lang['applangdir'] = 'ltr';
 
         // Bienvenido
 	$lang['strintro'] = 'Bienvenido a phpPgAdmin.';
@@ -65,6 +66,7 @@
 	$lang['strtrue'] = 'Verdadero';
 	$lang['strfalse'] = 'Falso';
 	$lang['stredit'] = 'Editar';
+        $lang['strcolumn']  =  'Columna';
 	$lang['strcolumns'] = 'Columnas';
 	$lang['strrows'] = 'fila(s)';
 	$lang['strrowsaff'] = 'fila(s) afectadas.';
@@ -92,14 +94,15 @@
 	$lang['strrun'] = 'Ejecutar';
 	$lang['stradd'] = 'Agregar';
 	$lang['strevent'] = 'Evento';
-	$lang['strwhere'] = 'Donde';
+	$lang['strwhere'] = 'Dnde';
 	$lang['strinstead'] = 'Hacer en su lugar';
-	$lang['strwhen'] = 'Cuando';
+	$lang['strwhen'] = 'Cundo';
 	$lang['strformat'] = 'Formato';
 	$lang['strdata'] = 'Dato';
 	$lang['strconfirm'] = 'Confirmar';
 	$lang['strexpression'] = 'Expresin';
 	$lang['strellipsis'] = '...';
+	$lang['strseparator']  =  ': ';
 	$lang['strexpand'] = 'Expandir';
 	$lang['strcollapse'] = 'Colapsar';
         $lang['strexplain'] = 'Explicar';
@@ -128,6 +131,8 @@
 	$lang['strnoframes'] = 'Necesits un navegador con soporte de marcos para usar esta aplicacin.';
 	$lang['strbadconfig'] = 'Su archivo config.inc.php est desactualizado. Deber regenerarlo a partir del archivo nuevo config.inc.php-dist.';
 	$lang['strnotloaded'] = 'Su versin de PHP no tiene el soporte correcto de bases de datos.';
+        $lang['strphpversionnotsupported']  =  'Su versin de PHP no est soportada. Por favor actualice a la versin %s o ms reciente.';
+        $lang['strpostgresqlversionnotsupported']  =  'Su versin de PostgreSQL no est soportado. Por favor actualice a la versin %s o ms reciente.';
 	$lang['strbadschema'] = 'El esquema especificado no es vlido.';
 	$lang['strbadencoding'] = 'No se pudo setear la codificacin del cliente en la base de datos.';
 	$lang['strsqlerror'] = 'Error de SQL:';
@@ -137,7 +142,7 @@
 	$lang['strnoobjects'] = 'No se encontraron objetos.';
 	$lang['strrownotunique'] = 'No existe un identificador nico para este registro.';
 	$lang['strnoreportsdb'] = 'No ha creado an la base de datos para los reportes. Lea las instrucciones del archivo INSTALL.';
-	$lang['strnouploads'] = 'Est desabilitada la subida de archivos.';
+	$lang['strnouploads'] = 'Est deshabilitada la subida de archivos.';
 	$lang['strimporterror'] = 'Error de importacin.';
 	$lang['strimporterrorline'] = 'Error de importacin en la lnea %s.';
 
@@ -170,11 +175,9 @@
 	$lang['strconfdeleterow'] = 'Est seguro que quiere eliminar esta fila?';
 	$lang['strrowdeleted'] = 'Fila eliminada.';
 	$lang['strrowdeletedbad'] = 'Fall la eliminacin de fila.';
-	$lang['strsaveandrepeat'] = 'Guardar y Repetir';
-	$lang['strfield'] = 'Campo';
-	$lang['strfields'] = 'Campos';
-	$lang['strnumfields'] = 'Nmero de Campos';
-	$lang['strfieldneedsname'] = 'Debe darle un nombre al campo';
+        $lang['strinsertandrepeat']  =  'Insertar y Repite';
+        $lang['strnumcols']  =  'Cantidad de columnas';
+        $lang['strcolneedsname']  =  'Debe especificar un nombre para la columna';
         $lang['strselectallfields'] = 'Seleccionar todos los campos.';
 	$lang['strselectneedscol'] = 'Debe elegir al menos una columna';
 	$lang['strselectunary'] = 'Operaciones unitarias no pueden tener valores.';
@@ -187,14 +190,16 @@
         $lang['straddcolumn'] = 'Agregar Columna';
 	$lang['strcolumnadded'] = 'Columna agregada.';
 	$lang['strcolumnaddedbad'] = 'Fall el agregado de columna.';
-	$lang['strdataonly'] = 'Datos solamente';
 	$lang['strcascade'] = 'EN CASCADA';
 	$lang['strtablealtered'] = 'Tabla modificada.';
 	$lang['strtablealteredbad'] = 'Fall la modificacin  de la Tabla.';
+        $lang['strdataonly'] = 'Datos solamente';
 	$lang['strstructureonly'] = 'Solo la estructura';
 	$lang['strstructureanddata'] = 'Estructura y datos';
 	$lang['strtabbed'] = 'Tabulado';
 	$lang['strauto'] = 'Automtico';
+        $lang['strconfvacuumtable']  =  'Esta seguro que quiere limpiar "%s"?';
+        $lang['strestimatedrowcount']  =  'Cantidad de filas estimadas';
 
         // Users
 	$lang['struser'] = 'Usuario';
@@ -213,8 +218,8 @@
 	$lang['struserneedsname'] = 'Debe dar un nombre a su usuario.';
 	$lang['strusercreated'] = 'Usuario creado.';
 	$lang['strusercreatedbad'] = 'Fall al crear usuario.';
-        $lang['struserdropped'] = 'Usuario eliminado.';
 	$lang['strconfdropuser'] = 'Est seguro que quiere eliminar el usuario "%s"?';
+        $lang['struserdropped'] = 'Usuario eliminado.';
 	$lang['struserdroppedbad'] = 'Fall al eliminar el usuario.';
 	$lang['straccount'] = 'Cuenta';
 	$lang['strchangepassword'] = 'Cambiar Contrasea';
@@ -224,8 +229,8 @@
 	$lang['strpasswordconfirm'] = 'Las contraseas no coinciden.';
 
         // Groups
-	$lang['strgroups'] = 'Grupos';
         $lang['strgroup'] = 'Grupo';
+	$lang['strgroups']  =  'Grupos';
 	$lang['strnogroup'] = 'Grupo no encontrado.';
 	$lang['strnogroups'] = 'No se encontraron grupos.';
 	$lang['strcreategroup'] = 'Crear Grupo';
@@ -235,6 +240,8 @@
 	$lang['strgroupcreatedbad'] = 'Fall la creacin del grupo.';
 	$lang['strconfdropgroup'] = 'Est seguro que quiere eliminar el grupo "%s"?';
 	$lang['strgroupdropped'] = 'Grupo eliminado.';
+        $lang['strgroupdroppedbad'] = 'Fall la eliminacin del grupo.';
+        $lang['strmembers'] = 'Miembros';
 	$lang['straddmember'] = 'Agregar un miembro';
 	$lang['strmemberadded'] = 'Miembro agregado.';
 	$lang['strmemberaddedbad'] = 'Fall al intentar agregar nuevo miembro.';
@@ -242,8 +249,6 @@
 	$lang['strconfdropmember'] = 'Est seguro que quiere sacra el miembro "%s" del grupo "%s"?';
 	$lang['strmemberdropped'] = 'Miembro eliminado.';
 	$lang['strmemberdroppedbad'] = 'Fall al intentar sacar un miembro.';
-	$lang['strgroupdroppedbad'] = 'Fall la eliminacin del grupo.';
-	$lang['strmembers'] = 'Miembros';
 
 	// Privilges
 	$lang['strprivilege'] = 'Privilegio';
@@ -253,10 +258,9 @@
 	$lang['strrevoke'] = 'Revocar';
 	$lang['strgranted'] = 'Privilegios otorgados/revocados.';
 	$lang['strgrantfailed'] = 'Fall al intentar otorgar privilegios.';
-        $lang['strgrantor'] = 'Cedente';
-        $lang['strasterisk'] = '*';
 	$lang['strgrantbad'] = 'Debe especificar al menos un usuario o grupo y al menos un privilegio.';
-	$lang['stralterprivs'] = 'Cambiar Privilegios';
+	$lang['strgrantor']  =  'Cedente';
+	$lang['strasterisk']  =  '*';
 
 	// Databases
 	$lang['strdatabase'] = 'Base de Datos';
@@ -283,6 +287,9 @@
 	$lang['strfull'] = 'Full';
 	$lang['strfreeze'] = 'Freeze';
 	$lang['strforce'] = 'Force';
+        $lang['strsignalsent']  =  'Seal enviada.';
+        $lang['strsignalsentbad']  =  'Fall el envo de la seal.';
+        $lang['strallobjects']  =  'Todos los objetos';
 
 	// Views
 	$lang['strview'] = 'Vista';
@@ -293,8 +300,8 @@
 	$lang['strcreateview'] = 'Crear Vista';
 	$lang['strviewname'] = 'Nombre de Vista';
 	$lang['strviewneedsname'] = 'Debe darle un nombre a la vista.';
-	$lang['strviewneedsfields'] = 'Seleccione por favor los campos que decea en su vista.';
 	$lang['strviewneedsdef'] = 'Debe darle una definicin a su vista.';
+        $lang['strviewneedsfields'] = 'Seleccione por favor los campos que desea en su vista.';
 	$lang['strviewcreated'] = 'Vista creada.';
 	$lang['strviewcreatedbad'] = 'Fall al crear la vista.';
 	$lang['strconfdropview'] = 'Est seguro que quiere eliminar la vista "%s"?';
@@ -339,7 +346,6 @@
 	$lang['strnoindex'] = 'No se encontr el ndice.';
 	$lang['strnoindexes'] = 'No se encontraron ndices.';
 	$lang['strcreateindex'] = 'Crear ndice';
-	$lang['strindexname'] = 'Nombre del ndice';
 	$lang['strtabname'] = 'Tab Name';
 	$lang['strcolumnname'] = 'Nombre de Columna';
 	$lang['strindexneedsname'] = 'Debe darle un nombre al ndice';
@@ -353,7 +359,6 @@
 	$lang['struniquekey'] = 'Llave nica';
 	$lang['strprimarykey'] = 'Llave primaria';
  	$lang['strindextype'] = 'Tipo de ndice';
-	$lang['strindexname'] = 'Nombre del ndice';
 	$lang['strtablecolumnlist'] = 'Columnas en Tabla';
 	$lang['strindexcolumnlist'] = 'Columnas en el ndice';
 	$lang['strconfcluster'] = 'Est seguro que quiere ordenar la tabla "%s"?';
@@ -413,7 +418,9 @@
 	$lang['strshowallfunctions'] = 'Mostrar todas las funciones';
 	$lang['strnofunction'] = 'No se encontr la funcin.';
 	$lang['strnofunctions'] = 'No se encontraron funciones.';
-	$lang['strcreatefunction'] = 'Crear funcin';
+        $lang['strcreateplfunction']  =  'Crear funcin SQL/PL';
+        $lang['strcreateinternalfunction']  =  'Crear funcin interna';
+        $lang['strcreatecfunction']  =  'Crear funcin en C';
 	$lang['strfunctionname'] = 'Nombre de la funcin';
 	$lang['strreturns'] = 'Devuelve';
 	$lang['strarguments'] = 'Argumentos';
@@ -427,6 +434,8 @@
 	$lang['strfunctiondroppedbad'] = 'Fall al eliminar la funcin.';
 	$lang['strfunctionupdated'] = 'Funcin actualizada.';
 	$lang['strfunctionupdatedbad'] = 'Fall al actualizar la funcin.';
+        $lang['strobjectfile']  =  'Archivo de objeto';
+        $lang['strlinksymbol']  =  'Vinculo simblico';
 
 	// Triggers
 	$lang['strtrigger'] = 'Disparador';
@@ -440,10 +449,10 @@
 	$lang['strtriggercreated'] = 'Disparador creado.';
 	$lang['strtriggercreatedbad'] = 'Fall la creacin del disparador.';
 	$lang['strconfdroptrigger'] = 'Est seguro que quiere eliminar el disparador "%s" en "%s"?';
-        $lang['strtriggeraltered'] = 'Disparador modificado.';
-        $lang['strtriggeralteredbad'] = 'Fall la modificacin del disparador.';
 	$lang['strtriggerdropped'] = 'Disparador eliminado.';
 	$lang['strtriggerdroppedbad'] = 'Fall al eliminar el disparador.';
+        $lang['strtriggeraltered'] = 'Disparador modificado.';
+        $lang['strtriggeralteredbad'] = 'Fall la modificacin del disparador.';
 
 	// Types
 	$lang['strtype'] = 'Tipo';
@@ -452,6 +461,9 @@
 	$lang['strnotype'] = 'No se encontr el tipo.';
 	$lang['strnotypes'] = 'No se encontraron tipos.';
 	$lang['strcreatetype'] = 'Crear Tipo';
+$lang['strcreatecomptype']  =  'Create composite type';
+        $lang['strtypeneedsfield']  =  'Debe especificar al menos un campo.';
+$lang['strtypeneedscols']  =  'Composite types require a valid number of columns.';	
 	$lang['strtypename'] = 'Nombre del tipo';
 	$lang['strinputfn'] = 'Funcin de entrada';
 	$lang['stroutputfn'] = 'Funcin de salida';
@@ -460,6 +472,8 @@
 	$lang['strelement'] = 'Elemento';
 	$lang['strdelimiter'] = 'Delimitador';
 	$lang['strstorage'] = 'Almacenamiento';
+        $lang['strfield']  =  'Campo';
+        $lang['strnumfields']  =  'Cantidad de campos';
 	$lang['strtypeneedsname'] = 'Debe especificar un nombre para el tipo.';
 	$lang['strtypeneedslen'] = 'Debe especificar una longitud para el tipo.';
 	$lang['strtypecreated'] = 'Tipo creado';
@@ -467,6 +481,10 @@
 	$lang['strconfdroptype'] = 'Est seguro que quiere eliminar el tipo "%s"?';
 	$lang['strtypedropped'] = 'Tipo eliminado.';
 	$lang['strtypedroppedbad'] = 'Fall al eliminar el tipo.';
+$lang['strflavor']  =  'Flavor';
+        $lang['strbasetype']  =  'Base';
+        $lang['strcompositetype']  =  'Compuesto';
+        $lang['strpseudotype']  =  'Pseudo';
 
 	// Schemas
 	$lang['strschema'] = 'Esquema';
@@ -484,6 +502,7 @@
 	$lang['strschemadroppedbad'] = 'Fall al eliminar el esquema.';
 	$lang['strschemaaltered'] = 'Esquema modificado.';
 	$lang['strschemaalteredbad'] = 'Modificacin del esquema fall.';
+        $lang['strsearchpath']  =  'Orden de busqueda en esquemas';
 
 	// Reports
 	$lang['strreport'] = 'Reporte';
@@ -591,9 +610,27 @@
 	$lang['strdisk'] = 'Disk';
 	$lang['strrows2'] = 'Rows';
 
+	// Tablespaces
+        $lang['strtablespace']  =  'Tablespace';
+        $lang['strtablespaces']  =  'Tablespaces';
+        $lang['strshowalltablespaces']  =  'Mostrar todos los tablespaces';
+        $lang['strnotablespaces']  =  'No se encontraron tablespaces.';
+        $lang['strcreatetablespace']  =  'Crear tablespace';
+        $lang['strlocation']  =  'Ubicacin';
+        $lang['strtablespaceneedsname']  =  'Debe darle un nombre al tablespace.';
+        $lang['strtablespaceneedsloc']  =  'Debe dar un directorio en donde crear el tablespace.';
+        $lang['strtablespacecreated']  =  'Tablespace creado.';
+        $lang['strtablespacecreatedbad']  =  'Fall la creacin del tablespace.';
+        $lang['strconfdroptablespace']  =  'Esta seguro que quiere eliminar el tablespace "%s"?';
+        $lang['strtablespacedropped']  =  'Tablespace eliminado.';
+        $lang['strtablespacedroppedbad']  =  'Fall al intenta eliminar el tablespace.';
+        $lang['strtablespacealtered']  =  'Tablespace modificado.';
+        $lang['strtablespacealteredbad']  =  'Fall la modificacin del Tablespace.';
+
 	// Miscellaneous
 	$lang['strtopbar'] = '%s corriendo en %s:%s -- Usted est logueado con usuario "%s", %s';
 	$lang['strtimefmt'] = 'd/m/Y, G:i:s';
 	$lang['strhelp'] = 'Ayuda';
+        $lang['strhelpicon']  =  '?';
 
 ?>
