@@ -3,7 +3,7 @@
 	/**
 	 * List tables in a database
 	 *
-	 * $Id: tables.php,v 1.53 2004/06/03 06:42:20 chriskl Exp $
+	 * $Id: tables.php,v 1.68 2004/10/11 10:29:15 jollytoad Exp $
 	 */
 
 	// Include application functions
@@ -23,10 +23,15 @@
 		if (!isset($_REQUEST['name'])) $_REQUEST['name'] = '';
 		if (!isset($_REQUEST['fields'])) $_REQUEST['fields'] = '';
 		if (!isset($_REQUEST['tblcomment'])) $_REQUEST['tblcomment'] = '';
+		if (!isset($_REQUEST['spcname'])) $_REQUEST['spcname'] = '';
 
 		switch ($_REQUEST['stage']) {
 			case 1:
-				echo "<h2>", $misc->printVal($_REQUEST['database']), ": {$lang['strtables']}: {$lang['strcreatetable']}</h2>\n";
+				// Fetch all tablespaces from the database
+				if ($data->hasTablespaces()) $tablespaces = &$data->getTablespaces();
+				
+				$misc->printTrail('schema');
+				$misc->printTitle($lang['strcreatetable'], 'pg.table.create');
 				$misc->printMsg($msg);
 				
 				echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
@@ -34,7 +39,7 @@
 				echo "\t<tr>\n\t\t<th class=\"data left required\">{$lang['strname']}</th>\n";
 				echo "\t\t<td class=\"data\"><input name=\"name\" size=\"32\" maxlength=\"{$data->_maxNameLen}\" value=\"", 
 					htmlspecialchars($_REQUEST['name']), "\" /></td>\n\t</tr>\n";
-				echo "\t<tr>\n\t\t<th class=\"data left required\">{$lang['strnumfields']}</th>\n";
+				echo "\t<tr>\n\t\t<th class=\"data left required\">{$lang['strnumcols']}</th>\n";
 				echo "\t\t<td class=\"data\"><input name=\"fields\" size=\"5\" maxlength=\"{$data->_maxNameLen}\" value=\"", 
 					htmlspecialchars($_REQUEST['fields']), "\" /></td>\n\t</tr>\n";
 				if ($data->hasWithoutOIDs()) {
@@ -42,6 +47,23 @@
 					echo "\t\t<td class=\"data\"><input type=\"checkbox\" name=\"withoutoids\"", 
 						(isset($_REQUEST['withoutoids']) ? ' checked="checked"' : ''), " />WITHOUT OIDS</td>\n\t</tr>\n";
 				}
+				
+				// Tablespace (if there are any)
+				if ($data->hasTablespaces() && $tablespaces->recordCount() > 0) {
+					echo "\t<tr>\n\t\t<th class=\"data left\">{$lang['strtablespace']}</th>\n";
+					echo "\t\t<td class=\"data1\">\n\t\t\t<select name=\"spcname\">\n";
+					// Always offer the default (empty) option
+					echo "\t\t\t\t<option value=\"\"",
+						($_REQUEST['spcname'] == '') ? ' selected="selected"' : '', "></option>\n";
+					// Display all other tablespaces
+					while (!$tablespaces->EOF) {
+						$spcname = htmlspecialchars($tablespaces->f['spcname']);
+						echo "\t\t\t\t<option value=\"{$spcname}\"",
+							($spcname == $_REQUEST['spcname']) ? ' selected="selected"' : '', ">{$spcname}</option>\n";
+						$tablespaces->moveNext();
+					}
+					echo "\t\t\t</select>\n\t\t</td>\n\t</tr>\n";
+				}
 
 				echo "\t<tr>\n\t\t<th class=\"data left\">{$lang['strcomment']}</th>\n";
 				echo "\t\t<td><textarea name=\"tblcomment\" rows=\"3\" cols=\"32\" wrap=\"virtual\">", 
@@ -71,16 +93,17 @@
 					return;
 				}
 
-				$types = &$data->getTypes(true);
+				$types = &$data->getTypes(true, false, true);
 	
-				echo "<h2>", $misc->printVal($_REQUEST['database']), ": {$lang['strtables']}: {$lang['strcreatetable']}</h2>\n";
+				$misc->printTrail('schema');
+				$misc->printTitle($lang['strcreatetable'], 'pg.table.create');
 				$misc->printMsg($msg);
 
 				echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
 
 				// Output table header
 				echo "<table>\n";
-				echo "\t<tr><th colspan=\"2\" class=\"data required\">{$lang['strfield']}</th><th colspan=\"2\" class=\"data required\">{$lang['strtype']}</th>";
+				echo "\t<tr><th colspan=\"2\" class=\"data required\">{$lang['strcolumn']}</th><th colspan=\"2\" class=\"data required\">{$lang['strtype']}</th>";
 				echo"<th class=\"data\">{$lang['strlength']}</th><th class=\"data\">{$lang['strnotnull']}</th><th class=\"data\">{$lang['strdefault']}</th><th class=\"data\">{$lang['strcomment']}</th></tr>\n";
 				
 				for ($i = 0; $i < $_REQUEST['fields']; $i++) {
@@ -101,7 +124,7 @@
 					}
 					$types->moveFirst();
 					while (!$types->EOF) {
-						$typname = $types->f[$data->typFields['typname']];
+						$typname = $types->f['typname'];
 						echo "\t\t\t\t<option value=\"", htmlspecialchars($typname), "\"",
 						(isset($_REQUEST['type'][$i]) && $typname == $_REQUEST['type'][$i]) ? ' selected="selected"' : '', ">",
 							$misc->printVal($typname), "</option>\n";
@@ -133,6 +156,9 @@
 					echo "<input type=\"hidden\" name=\"withoutoids\" value=\"true\" />\n";
 				}
 				echo "<input type=\"hidden\" name=\"tblcomment\" value=\"", htmlspecialchars($_REQUEST['tblcomment']), "\" />\n";
+				if (isset($_REQUEST['spcname'])) {
+					echo "<input type=\"hidden\" name=\"spcname\" value=\"", htmlspecialchars($_REQUEST['spcname']), "\" />\n";
+				}
 				echo "<input type=\"submit\" value=\"{$lang['strcreate']}\" />\n";
 				echo "<input type=\"submit\" name=\"cancel\" value=\"{$lang['strcancel']}\" /></p>\n";
 				echo "</form>\n";
@@ -142,6 +168,8 @@
 				global $data, $lang, $_reload_browser;
 
 				if (!isset($_REQUEST['notnull'])) $_REQUEST['notnull'] = array();
+				// Default tablespace to null if it isn't set
+				if (!isset($_REQUEST['spcname'])) $_REQUEST['spcname'] = null;
 
 				// Check inputs
 				$fields = trim($_REQUEST['fields']);
@@ -158,7 +186,7 @@
 				
 				$status = $data->createTable($_REQUEST['name'], $_REQUEST['fields'], $_REQUEST['field'],
 								$_REQUEST['type'], $_REQUEST['array'], $_REQUEST['length'], $_REQUEST['notnull'], $_REQUEST['default'],
-								isset($_REQUEST['withoutoids']), $_REQUEST['colcomment'], $_REQUEST['tblcomment']);
+								isset($_REQUEST['withoutoids']), $_REQUEST['colcomment'], $_REQUEST['tblcomment'], $_REQUEST['spcname']);
 
 				if ($status == 0) {
 					$_reload_browser = true;
@@ -176,7 +204,6 @@
 				}
 				break;
 			default:
-				global $lang;
 				echo "<p>{$lang['strinvalidparam']}</p>\n";
 		}
 	}
@@ -190,7 +217,8 @@
 		global $PHP_SELF;
 
 		if ($confirm) {
-			echo "<h2>", $misc->printVal($_REQUEST['database']), ": {$lang['strtables']}: ", $misc->printVal($_REQUEST['table']), ": {$lang['strselect']}</h2>\n";
+			$misc->printTrail('table');
+			$misc->printTitle($lang['strselect'], 'pg.sql.select');
 			$misc->printMsg($msg);
 
 			$attrs = &$data->getTableAttributes($_REQUEST['table']);
@@ -212,7 +240,7 @@
 				echo "<table>\n<tr>";
 
 				// Output table header
-				echo "<tr><th class=\"data\">{$lang['strshow']}</th><th class=\"data\">{$lang['strfield']}</th>";
+				echo "<tr><th class=\"data\">{$lang['strshow']}</th><th class=\"data\">{$lang['strcolumn']}</th>";
 				echo "<th class=\"data\">{$lang['strtype']}</th><th class=\"data\">{$lang['stroperator']}</th>";
 				echo "<th class=\"data\">{$lang['strvalue']}</th></tr>";
 
@@ -253,6 +281,7 @@
 
 			echo "<p><input type=\"hidden\" name=\"action\" value=\"selectrows\" />\n";
 			echo "<input type=\"hidden\" name=\"table\" value=\"", htmlspecialchars($_REQUEST['table']), "\" />\n";
+			echo "<input type=\"hidden\" name=\"subject\" value=\"table\" />\n";
 			echo $misc->form;
 			echo "<input type=\"submit\" name=\"select\" value=\"{$lang['strselect']}\" />\n";
 			echo "<input type=\"submit\" name=\"cancel\" value=\"{$lang['strcancel']}\" /></p>\n";
@@ -297,7 +326,8 @@
 		global $PHP_SELF;
 
 		if ($confirm) {
-			echo "<h2>", $misc->printVal($_REQUEST['database']), ": {$lang['strtables']}: ", $misc->printVal($_REQUEST['table']), ": {$lang['strinsertrow']}</h2>\n";
+			$misc->printTrail('table');
+			$misc->printTitle($lang['strinsertrow'], 'pg.sql.insert');
 			$misc->printMsg($msg);
 
 			$attrs = &$data->getTableAttributes($_REQUEST['table']);
@@ -307,7 +337,7 @@
 				echo "<table>\n";
 
 				// Output table header
-				echo "<tr><th class=\"data\">{$lang['strfield']}</th><th class=\"data\">{$lang['strtype']}</th>";
+				echo "<tr><th class=\"data\">{$lang['strcolumn']}</th><th class=\"data\">{$lang['strtype']}</th>";
 				echo "<th class=\"data\">{$lang['strformat']}</th>";
 				echo "<th class=\"data\">{$lang['strnull']}</th><th class=\"data\">{$lang['strvalue']}</th></tr>";
 				
@@ -317,8 +347,8 @@
 					// Set up default value if there isn't one already
 					if (!isset($_REQUEST['values'][$attrs->f['attname']]))
 						$_REQUEST['values'][$attrs->f['attname']] = $attrs->f['adsrc'];
-					// Default format to 'LITERAL' if there is no default, otherwise
-					// default to 'EXPRESSION'...
+					// Default format to 'VALUE' if there is no default,
+					// otherwise default to 'EXPRESSION'
 					if (!isset($_REQUEST['format'][$attrs->f['attname']]))
 						$_REQUEST['format'][$attrs->f['attname']] = ($attrs->f['adsrc'] === null) ? 'VALUE' : 'EXPRESSION';
 					// Continue drawing row
@@ -354,8 +384,8 @@
 			echo "<input type=\"hidden\" name=\"action\" value=\"insertrow\" />\n";
 			echo "<input type=\"hidden\" name=\"table\" value=\"", htmlspecialchars($_REQUEST['table']), "\" />\n";
 			echo $misc->form;
-			echo "<p><input type=\"submit\" name=\"save\" value=\"{$lang['strinsert']}\" />\n";
-			echo "<input type=\"submit\" name=\"saveandrepeat\" value=\"{$lang['strsaveandrepeat']}\" />\n";
+			echo "<p><input type=\"submit\" name=\"insert\" value=\"{$lang['strinsert']}\" />\n";
+			echo "<input type=\"submit\" name=\"insertandrepeat\" value=\"{$lang['strinsertandrepeat']}\" />\n";
 			echo "<input type=\"submit\" name=\"cancel\" value=\"{$lang['strcancel']}\" /></p>\n";
 			echo "</form>\n";
 		}
@@ -366,7 +396,7 @@
 			$status = $data->insertRow($_POST['table'], $_POST['values'], 
 												$_POST['nulls'], $_POST['format'], $_POST['types']);
 			if ($status == 0) {
-				if (isset($_POST['save']))
+				if (isset($_POST['insert']))
 					doDefault($lang['strrowinserted']);
 				else {
 					$_REQUEST['values'] = array();
@@ -389,7 +419,8 @@
 		global $PHP_SELF;
 
 		if ($confirm) {
-			echo "<h2>", $misc->printVal($_REQUEST['database']), ": {$lang['strtables']}: ", $misc->printVal($_REQUEST['table']), ": {$lang['strempty']}</h2>\n";
+			$misc->printTrail('table');
+			$misc->printTitle($lang['strempty'],'pg.table.empty');
 
 			echo "<p>", sprintf($lang['strconfemptytable'], $misc->printVal($_REQUEST['table'])), "</p>\n";
 
@@ -419,7 +450,8 @@
 		global $PHP_SELF;
 
 		if ($confirm) {
-			echo "<h2>", $misc->printVal($_REQUEST['database']), ": {$lang['strtables']}: ", $misc->printVal($_REQUEST['table']), ": {$lang['strdrop']}</h2>\n";
+			$misc->printTrail('table');
+			$misc->printTitle($lang['strdrop'], 'pg.table.drop');
 
 			echo "<p>", sprintf($lang['strconfdroptable'], $misc->printVal($_REQUEST['table'])), "</p>\n";
 
@@ -447,6 +479,46 @@
 		
 	}
 
+
+	/**
+	 * Show confirmation of vacuum and perform actual vacuum
+	 */
+	function doVacuum($confirm) {
+		global $data, $misc;
+		global $lang, $_reload_browser;
+		global $PHP_SELF;
+
+		if ($confirm) {
+			$misc->printTrail('table');
+			$misc->printTitle($lang['strvacuum'], 'pg.vacuum');
+
+			echo "<p>", sprintf($lang['strconfvacuumtable'], $misc->printVal($_REQUEST['table'])), "</p>\n";
+
+			echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
+			echo "<input type=\"hidden\" name=\"action\" value=\"vacuum\" />\n";
+			echo "<input type=\"hidden\" name=\"table\" value=\"", htmlspecialchars($_REQUEST['table']), "\" />\n";
+			echo $misc->form;
+			// Show vacuum full option if supportd
+			if ($data->hasFullVacuum()) {
+				echo "<p><input type=\"checkbox\" name=\"vacuum_full\" /> {$lang['strfull']}</p>\n";
+				echo "<p><input type=\"checkbox\" name=\"vacuum_analyze\" /> {$lang['stranalyze']}</p>\n";
+			}
+			echo "<input type=\"submit\" name=\"vacuum\" value=\"{$lang['strvacuum']}\" />\n";
+			echo "<input type=\"submit\" name=\"cancel\" value=\"{$lang['strcancel']}\" />\n";
+			echo "</form>\n";
+		}
+		else {
+			$status = $data->vacuumDB($_POST['table'], isset($_REQUEST['vacuum_analyze']), isset($_REQUEST['vacuum_full']), '');
+			if ($status == 0) {
+				$_reload_browser = true;
+				doDefault($lang['strvacuumgood']);
+			}
+			else
+				doDefault($lang['strvacuumbad']);
+		}
+		
+	}
+
 	/**
 	 * Show default list of tables in the database
 	 */
@@ -454,49 +526,80 @@
 		global $data, $conf, $misc, $data;
 		global $PHP_SELF, $lang;
 		
-		echo "<h2>", $misc->printVal($_REQUEST['database']), ": {$lang['strtables']}</h2>\n";
-			
+		$misc->printTrail('schema');
+		$misc->printTabs('schema','tables');
+		$misc->printMsg($msg);
+		
 		$tables = &$data->getTables();
 		
-		if ($tables->recordCount() > 0) {
-			echo "<table>\n";
-			echo "<tr>\n\t<th class=\"data\">{$lang['strtable']}</th>\n\t<th class=\"data\">{$lang['strowner']}</th>\n";
-			echo "\t<th colspan=\"6\" class=\"data\">{$lang['stractions']}</th>\n";
-			if ($conf['show_comments']) echo "\t<th class=\"data\">{$lang['strcomment']}</th>\n";
-			echo "</tr>\n";
-			$i = 0;
-			while (!$tables->EOF) {
-				$return_url = urlencode("tables.php?{$misc->href}");
-				$id = (($i % 2) == 0 ? '1' : '2');
-				echo "<tr>\n\t<td class=\"data{$id}\">", $misc->printVal($tables->f[$data->tbFields['tbname']]), "</td>\n";
-				echo "\t<td class=\"data{$id}\">", $misc->printVal($tables->f[$data->tbFields['tbowner']]), "</td>\n";
-				echo "\t<td class=\"opbutton{$id}\"><a href=\"display.php?{$misc->href}&amp;table=",
-					urlencode($tables->f[$data->tbFields['tbname']]), "&amp;return_url={$return_url}&amp;return_desc=",
-					urlencode($lang['strback']), "\">{$lang['strbrowse']}</a></td>\n";
-				echo "\t<td class=\"opbutton{$id}\"><a href=\"$PHP_SELF?action=confselectrows&amp;{$misc->href}&amp;table=",
-					urlencode($tables->f[$data->tbFields['tbname']]), "\">{$lang['strselect']}</a></td>\n";
-				echo "\t<td class=\"opbutton{$id}\"><a href=\"$PHP_SELF?action=confinsertrow&amp;{$misc->href}&amp;table=",
-					urlencode($tables->f[$data->tbFields['tbname']]), "\">{$lang['strinsert']}</a></td>\n";
-				echo "\t<td class=\"opbutton{$id}\"><a href=\"tblproperties.php?{$misc->href}&amp;table=",
-					urlencode($tables->f[$data->tbFields['tbname']]), "\">{$lang['strproperties']}</a></td>\n";
-				echo "\t<td class=\"opbutton{$id}\"><a href=\"$PHP_SELF?action=confirm_empty&amp;{$misc->href}&amp;table=",
-					urlencode($tables->f[$data->tbFields['tbname']]), "\">{$lang['strempty']}</a></td>\n";
-				echo "\t<td class=\"opbutton{$id}\"><a href=\"$PHP_SELF?action=confirm_drop&amp;{$misc->href}&amp;table=",
-					urlencode($tables->f[$data->tbFields['tbname']]), "\">{$lang['strdrop']}</a></td>\n";
-				// Trim long comments
-				if (strlen($tables->f['tablecomment']) > $conf['max_chars']) {
-					$tables->f['tablecomment'] = substr($tables->f['tablecomment'], 0, $conf['max_chars'] - 1) . $lang['strellipsis'];
-				}
-				if ($conf['show_comments']) echo "\t<td class=\"data{$id}\">", $misc->printVal($tables->f['tablecomment']), "</td>\n";
-				echo "</tr>\n";
-				$tables->moveNext();
-				$i++;
-			}
-			echo "</table>\n";
-		}
-		else {
-			echo "<p>{$lang['strnotables']}</p>\n";
-		}
+		$columns = array(
+			'table' => array(
+				'title' => $lang['strtable'],
+				'field' => 'relname',
+			),
+			'owner' => array(
+				'title' => $lang['strowner'],
+				'field' => 'relowner',
+			),
+			'tablespace' => array(
+				'title' => $lang['strtablespace'],
+				'field' => 'tablespace'
+			),
+			'tuples' => array(
+				'title' => $lang['strestimatedrowcount'],
+				'field' => 'reltuples',
+				'type'  => 'numeric'
+			),
+			'actions' => array(
+				'title' => $lang['stractions'],
+			),
+			'comment' => array(
+				'title' => $lang['strcomment'],
+				'field' => 'relcomment',
+			),
+		);
+		
+		$actions = array(
+			'properties' => array(
+				'title' => $lang['strproperties'],
+				'url'   => "redirect.php?section=table&amp;{$misc->href}&amp;",
+				'vars'  => array('table' => 'relname'),
+			),
+			'browse' => array(
+				'title' => $lang['strbrowse'],
+				'url'   => "display.php?{$misc->href}&amp;subject=table&amp;return_url=".urlencode("tables.php?{$misc->href}")."&amp;return_desc=".urlencode($lang['strback'])."&amp;",
+				'vars'  => array('table' => 'relname'),
+			),
+			'select' => array(
+				'title' => $lang['strselect'],
+				'url'   => "{$PHP_SELF}?action=confselectrows&amp;{$misc->href}&amp;",
+				'vars'  => array('table' => 'relname'),
+			),
+			'insert' => array(
+				'title' => $lang['strinsert'],
+				'url'   => "{$PHP_SELF}?action=confinsertrow&amp;{$misc->href}&amp;",
+				'vars'  => array('table' => 'relname'),
+			),
+			'empty' => array(
+				'title' => $lang['strempty'],
+				'url'   => "{$PHP_SELF}?action=confirm_empty&amp;{$misc->href}&amp;",
+				'vars'  => array('table' => 'relname'),
+			),
+			'drop' => array(
+				'title' => $lang['strdrop'],
+				'url'   => "{$PHP_SELF}?action=confirm_drop&amp;{$misc->href}&amp;",
+				'vars'  => array('table' => 'relname'),
+			),
+			'vacuum' => array(
+				'title' => $lang['strvacuum'],
+				'url'   => "{$PHP_SELF}?action=confirm_vacuum&amp;{$misc->href}&amp;",
+				'vars'  => array('table' => 'relname'),
+			),
+		);
+		
+		if (!$data->hasTablespaces()) unset($columns['tablespace']);
+
+		$misc->printTable($tables, $columns, $actions, $lang['strnotables']);
 
 		echo "<p><a class=\"navlink\" href=\"$PHP_SELF?action=create&amp;{$misc->href}\">{$lang['strcreatetable']}</a></p>\n";
 	}
@@ -537,6 +640,13 @@
 		case 'confirm_drop':
 			doDrop(true);
 			break;
+		case 'vacuum':
+			if (isset($_POST['vacuum'])) doVacuum(false);
+			else doDefault();
+			break;
+		case 'confirm_vacuum':
+			doVacuum(true);
+			break;
 		default:
 			doDefault();
 			break;
