@@ -3,7 +3,7 @@
 	/**
 	 * List tables in a database
 	 *
-	 * $Id: tblproperties.php,v 1.48 2004/05/31 13:25:49 chriskl Exp $
+	 * $Id: tblproperties.php,v 1.62 2004/11/02 03:33:35 chriskl Exp $
 	 */
 
 	// Include application functions
@@ -20,8 +20,10 @@
 
 		// For databases that don't allow owner change
 		if (!isset($_POST['owner'])) $_POST['owner'] = '';
+		// Default tablespace to null if it isn't set
+		if (!isset($_POST['tablespace'])) $_POST['tablespace'] = null;
 		
-		$status = $data->alterTable($_POST['table'], $_POST['name'], $_POST['owner'], $_POST['comment']);
+		$status = $data->alterTable($_POST['table'], $_POST['name'], $_POST['owner'], $_POST['comment'], $_POST['tablespace']);
 		if ($status == 0) {
 			// If table has been renamed, need to change to the new name and
 			// reload the browser frame.
@@ -44,38 +46,60 @@
 		global $data, $misc;
 		global $PHP_SELF, $lang;
 		
-		echo "<h2>", $misc->printVal($_REQUEST['database']), ": ", $misc->printVal($_REQUEST['table']), ": {$lang['stralter']}</h2>\n";
+		$misc->printTrail('table');
+		$misc->printTitle($lang['stralter'], 'pg.table.alter');
 		$misc->printMsg($msg);
 
 		// Fetch table info		
 		$table = &$data->getTable($_REQUEST['table']);
 		// Fetch all users
 		$users = &$data->getUsers();
+		// Fetch all tablespaces from the database
+		if ($data->hasTablespaces()) $tablespaces = &$data->getTablespaces(true);
 		
 		if ($table->recordCount() > 0) {
 			
-			if (!isset($_POST['name'])) $_POST['name'] = $table->f[$data->tbFields['tbname']];
-			if (!isset($_POST['owner'])) $_POST['owner'] = $table->f[$data->tbFields['tbowner']];
-			if (!isset($_POST['comment'])) $_POST['comment'] = $table->f[$data->tbFields['tbcomment']];
+			if (!isset($_POST['name'])) $_POST['name'] = $table->f['relname'];
+			if (!isset($_POST['owner'])) $_POST['owner'] = $table->f['relowner'];
+			if (!isset($_POST['comment'])) $_POST['comment'] = $table->f['relcomment'];
+			if ($data->hasTablespaces() && !isset($_POST['tablespace'])) $_POST['tablespace'] = $table->f['tablespace'];
 			
 			echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
 			echo "<table>\n";
-			echo "<tr><th class=\"data required\">{$lang['strname']}</th>\n";
+			echo "<tr><th class=\"data left required\">{$lang['strname']}</th>\n";
 			echo "<td class=\"data1\">";
 			echo "<input name=\"name\" size=\"32\" maxlength=\"{$data->_maxNameLen}\" value=\"", 
 				htmlspecialchars($_POST['name']), "\" /></td></tr>\n";
 			if ($data->hasAlterTableOwner() && $data->isSuperUser($_SESSION['webdbUsername'])) {
-				echo "<tr><th class=\"data required\">{$lang['strowner']}</th>\n";
+				echo "<tr><th class=\"data left required\">{$lang['strowner']}</th>\n";
 				echo "<td class=\"data1\"><select name=\"owner\">";
 				while (!$users->EOF) {
-					$uname = $users->f[$data->uFields['uname']];
+					$uname = $users->f['usename'];
 					echo "<option value=\"", htmlspecialchars($uname), "\"",
 						($uname == $_POST['owner']) ? ' selected="selected"' : '', ">", htmlspecialchars($uname), "</option>\n";
 					$users->moveNext();
 				}
 				echo "</select></td></tr>\n";				
 			}
-			echo "<tr><th class=\"data\">{$lang['strcomment']}</th>\n";
+
+			// Tablespace (if there are any)
+			if ($data->hasTablespaces() && $tablespaces->recordCount() > 0) {
+				echo "\t<tr>\n\t\t<th class=\"data left\">{$lang['strtablespace']}</th>\n";
+				echo "\t\t<td class=\"data1\">\n\t\t\t<select name=\"tablespace\">\n";
+				// Always offer the default (empty) option
+				echo "\t\t\t\t<option value=\"\"",
+					($_POST['tablespace'] == '') ? ' selected="selected"' : '', "></option>\n";
+				// Display all other tablespaces
+				while (!$tablespaces->EOF) {
+					$spcname = htmlspecialchars($tablespaces->f['spcname']);
+					echo "\t\t\t\t<option value=\"{$spcname}\"",
+						($spcname == $_POST['tablespace']) ? ' selected="selected"' : '', ">{$spcname}</option>\n";
+					$tablespaces->moveNext();
+				}
+				echo "\t\t\t</select>\n\t\t</td>\n\t</tr>\n";
+			}
+			
+			echo "<tr><th class=\"data left\">{$lang['strcomment']}</th>\n";
 			echo "<td class=\"data1\">";
 			echo "<textarea rows=\"3\" cols=\"32\" name=\"comment\" wrap=\"virtual\">",
 				htmlspecialchars($_POST['comment']), "</textarea></td></tr>\n";
@@ -97,8 +121,8 @@
 		// Determine whether or not the table has an object ID
 		$hasID = $data->hasObjectID($_REQUEST['table']);
 		
-		$misc->printTableNav();
-		echo "<h2>", $misc->printVal($_REQUEST['database']), ": ", $misc->printVal($_REQUEST['table']), ": {$lang['strexport']}</h2>\n";
+		$misc->printTrail('table');
+		$misc->printTabs('table','export');
 		$misc->printMsg($msg);
 
 		echo "<form action=\"dataexport.php\" method=\"post\">\n";
@@ -151,8 +175,8 @@
 		global $data, $misc;
 		global $PHP_SELF, $lang;
 
-		$misc->printTableNav();
-		echo "<h2>", $misc->printVal($_REQUEST['database']), ": ", $misc->printVal($_REQUEST['table']), ": {$lang['strimport']}</h2>\n";
+		$misc->printTrail('table');
+		$misc->printTabs('table','import');
 		$misc->printMsg($msg);
 
 		// Check that file uploads are enabled
@@ -207,17 +231,17 @@
 				if (!isset($_POST['comment'])) $_POST['comment'] = '';
 
 				// Fetch all available types
-				$types = &$data->getTypes(true);
+				$types = &$data->getTypes(true, false, true);
 
-				echo "<h2>", $misc->printVal($_REQUEST['database']), ": ",
-					$misc->printVal($_REQUEST['table']), ": {$lang['straddcolumn']}</h2>\n";
+				$misc->printTrail('table');
+				$misc->printTitle($lang['straddcolumn'], 'pg.column.add');
 				$misc->printMsg($msg);
 
 				echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
 
 				// Output table header
 				echo "<table>\n<tr>";
-				echo "<tr><th class=\"data required\">{$lang['strfield']}</th><th colspan=\"2\" class=\"data required\">{$lang['strtype']}</th>";
+				echo "<tr><th class=\"data required\">{$lang['strcolumn']}</th><th colspan=\"2\" class=\"data required\">{$lang['strtype']}</th>";
 				echo "<th class=\"data\">{$lang['strlength']}</th>";
 				if ($data->hasAlterColumnType()) echo "<th class=\"data\">{$lang['strnotnull']}</th><th class=\"data\">{$lang['strdefault']}</th>";
 				echo "<th class=\"data\">{$lang['strcomment']}</th></tr>";
@@ -234,7 +258,7 @@
 					}
 				}
 				while (!$types->EOF) {
-					$typname = $types->f[$data->typFields['typname']];
+					$typname = $types->f['typname'];
 					echo "<option value=\"", htmlspecialchars($typname), "\"", ($typname == $_POST['type']) ? ' selected="selected"' : '', ">",
 						$misc->printVal($typname), "</option>\n";
 					$types->moveNext();
@@ -249,13 +273,16 @@
 
 				echo "<td><input name=\"length\" size=\"8\" value=\"",
 					htmlspecialchars($_POST['length']), "\" /></td>";
-				// Support for adding column with not null and default (7.5+ only)
+				// Support for adding column with not null and default
 				if ($data->hasAlterColumnType()) {					
 					echo "<td><input type=\"checkbox\" name=\"notnull\"", 
 						(isset($_REQUEST['notnull'])) ? ' checked="checked"' : '', " /></td>\n";
 					echo "<td><input name=\"default\" size=\"20\" value=\"",
 						htmlspecialchars($_POST['default']), "\" /></td>";
 				}
+				else {
+					echo "<input type=\"hidden\" name=\"default\" value=\"\" />\n";	
+				}
 				echo "<td><input name=\"comment\" size=\"40\" value=\"",
 					htmlspecialchars($_POST['comment']), "\" /></td></tr>";
 				echo "</table>\n";
@@ -274,12 +301,13 @@
 				// Check inputs
 				if (trim($_POST['field']) == '') {
 					$_REQUEST['stage'] = 1;
-					doAddColumn($lang['strfieldneedsname']);
+					doAddColumn($lang['strcolneedsname']);
 					return;
 				}
-				
+
 				$status = $data->addColumn($_POST['table'], $_POST['field'],
-							   $_POST['type'], $_POST['array'] != '', $_POST['length'], $_POST['comment']);
+							   $_POST['type'], $_POST['array'] != '', $_POST['length'], isset($_POST['notnull']),
+							   $_POST['default'], $_POST['comment']);
 				if ($status == 0)
 					doDefault($lang['strcolumnadded']);
 				else {
@@ -306,8 +334,8 @@
 			case 1:
 				global $lang;
 
-				echo "<h2>", $misc->printVal($_REQUEST['database']), ": {$lang['strtables']}: {$lang['straltercolumn']}: ",
-					$misc->printVal($_REQUEST['column']), "</h2>\n";
+				$misc->printTrail('column');
+				$misc->printTitle($lang['straltercolumn'], 'pg.column.alter'); 
 				$misc->printMsg($msg);
 
 				echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
@@ -358,10 +386,10 @@
 				echo "<tr><td><input name=\"field\" size=\"32\" value=\"",
 					htmlspecialchars($_REQUEST['field']), "\" /></td>";
 					
-				// Column type.  On 7.5+ this can be altered
+				// Column type
 				if ($data->hasAlterColumnType()) {
 					// Fetch all available types
-					$types = &$data->getTypes(true);
+					$types = &$data->getTypes(true, false, true);
 					
 					echo "<td><select name=\"type\">\n";				
 					// Output any "magic" types.  This came in with Alter Column Type so we don't need to check that
@@ -371,7 +399,7 @@
 							$misc->printVal($v), "</option>\n";
 					}
 					while (!$types->EOF) {
-						$typname = $types->f[$data->typFields['typname']];
+						$typname = $types->f['typname'];
 						echo "<option value=\"", htmlspecialchars($typname), "\"", ($typname == $_REQUEST['type']) ? ' selected="selected"' : '', ">",
 							$misc->printVal($typname), "</option>\n";
 						$types->moveNext();
@@ -423,7 +451,7 @@
 				// Check inputs
 				if (trim($_REQUEST['field']) == '') {
 					$_REQUEST['stage'] = 1;
-					doProperties($lang['strfieldneedsname']);
+					doProperties($lang['strcolneedsname']);
 					return;
 				}
 
@@ -453,11 +481,11 @@
 		global $PHP_SELF, $lang;
 
 		if ($confirm) {
-			echo "<h2>", $misc->printVal($_REQUEST['database']), ": {$lang['strtables']}: ", 
-				$misc->printVal($_REQUEST['table']), ": " , $misc->printVal($_REQUEST['column']), ": {$lang['strdrop']}</h2>\n";
+			$misc->printTrail('column');
+			$misc->printTitle($lang['strdrop'], 'pg.column.drop');
 
-                        echo "<p>", sprintf($lang['strconfdropcolumn'], $misc->printVal($_REQUEST['column']),
-                                $misc->printVal($_REQUEST['table'])), "</p>\n";
+            echo "<p>", sprintf($lang['strconfdropcolumn'], $misc->printVal($_REQUEST['column']),
+                    $misc->printVal($_REQUEST['table'])), "</p>\n";
 								
 
 			echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
@@ -490,54 +518,74 @@
 		global $data, $conf, $misc;
 		global $PHP_SELF, $lang;
 
-		$misc->printTableNav();
-		echo "<h2>", $misc->printVal($_REQUEST['database']), ": ", $misc->printVal($_REQUEST['table']), "</h2>\n";
+		function attPre(&$rowdata) {
+			global $data;
+			$rowdata->f['+type'] = $data->formatType($rowdata->f['type'], $rowdata->f['atttypmod']);
+		}
+		
+		$misc->printTrail('table');
+		$misc->printTabs('table','columns');
+		$misc->printMsg($msg);
 
 		// Get table
 		$tdata = &$data->getTable($_REQUEST['table']);
 		// Get columns
 		$attrs = &$data->getTableAttributes($_REQUEST['table']);		
-		$misc->printMsg($msg);
 
 		// Show comment if any
-		if ($tdata->f[$data->tbFields['tbcomment']] !== null)
-			echo "<p class=\"comment\">", $misc->printVal($tdata->f[$data->tbFields['tbcomment']]), "</p>\n";
+		if ($tdata->f['relcomment'] !== null)
+			echo "<p class=\"comment\">", $misc->printVal($tdata->f['relcomment']), "</p>\n";
 
-		echo "<table>\n";
-		echo "<tr>\n\t<th class=\"data\">{$lang['strfield']}</th>\n\t<th class=\"data\">{$lang['strtype']}</th>\n";
-		echo "\t<th class=\"data\">{$lang['strnotnull']}</th>\n\t<th class=\"data\">{$lang['strdefault']}</th>\n";
-		if ($data->hasDropColumn())
-			echo "\t<th colspan=\"2\" class=\"data\">{$lang['stractions']}</th>\n";
-		else
-			echo "\t<th class=\"data\">{$lang['stractions']}</th>\n";
-		if ($conf['show_comments']) echo "\t<th class=\"data\">{$lang['strcomment']}</th>\n"; 
-		echo "</tr>\n";
-
-		$i = 0;
-		while (!$attrs->EOF) {
-			$attrs->f['attnotnull'] = $data->phpBool($attrs->f['attnotnull']);
-			$id = (($i % 2) == 0 ? '1' : '2');
-			echo "<tr>\n\t<td class=\"data{$id}\">", $misc->printVal($attrs->f['attname']), "</td>\n";
-			echo "\t<td class=\"data{$id}\">", $misc->printVal($data->formatType($attrs->f['type'], $attrs->f['atttypmod'])), "</td>\n";
-			echo "\t<td class=\"data{$id}\">", ($attrs->f['attnotnull'] ? 'NOT NULL' : ''), "</td>\n";
-			echo "\t<td class=\"data{$id}\">", $misc->printVal($attrs->f['adsrc']), "</td>\n";
-			echo "\t<td class=\"opbutton{$id}\"><a href=\"{$PHP_SELF}?{$misc->href}&table=", urlencode($_REQUEST['table']),
-				"&column=", urlencode($attrs->f['attname']), "&action=properties\">{$lang['stralter']}</a></td>\n";
-			if ($data->hasDropColumn()) {
-				echo "\t<td class=\"opbutton{$id}\"><a href=\"{$PHP_SELF}?{$misc->href}&table=", urlencode($_REQUEST['table']),
-					"&column=", urlencode($attrs->f['attname']), "&action=confirm_drop\">{$lang['strdrop']}</a></td>\n";
-			}
-			if ($conf['show_comments']) echo "\t<td class=\"data{$id}\">", $misc->printVal($attrs->f['comment']), "</td>\n"; 
-			echo "</tr>\n";
-			$attrs->moveNext();
-			$i++;
-		}
-		echo "</table>\n";
+		$columns = array(
+			'column' => array(
+				'title' => $lang['strcolumn'],
+				'field' => 'attname',
+			),
+			'type' => array(
+				'title' => $lang['strtype'],
+				'field' => '+type',
+			),
+			'notnull' => array(
+				'title' => $lang['strnotnull'],
+				'field' => 'attnotnull',
+				'type'  => 'bool',
+				'params'=> array('true' => 'NOT NULL', 'false' => ''),
+			),
+			'default' => array(
+				'title' => $lang['strdefault'],
+				'field' => 'adsrc',
+			),
+			'actions' => array(
+				'title' => $lang['stractions'],
+			),
+			'comment' => array(
+				'title' => $lang['strcomment'],
+				'field' => 'comment',
+			),
+		);
+		
+		$actions = array(
+			'alter' => array(
+				'title' => $lang['stralter'],
+				'url'   => "{$PHP_SELF}?action=properties&amp;{$misc->href}&amp;table=".urlencode($_REQUEST['table'])."&amp;",
+				'vars'  => array('column' => 'attname'),
+			),
+			'drop' => array(
+				'title' => $lang['strdrop'],
+				'url'   => "{$PHP_SELF}?action=confirm_drop&amp;{$misc->href}&amp;table=".urlencode($_REQUEST['table'])."&amp;",
+				'vars'  => array('column' => 'attname'),
+			),
+		);
+		
+		if (!$data->hasDropColumn()) unset($actions['drop']);
+		
+		$misc->printTable($attrs, $columns, $actions, null, 'attPre');
+		
 		echo "<br />\n";
 
 		echo "<ul>\n";
 		$return_url = urlencode("tblproperties.php?{$misc->href}&table={$_REQUEST['table']}");
-		echo "\t<li><a href=\"display.php?{$misc->href}&table=", urlencode($_REQUEST['table']), "&return_url={$return_url}&return_desc=",
+		echo "\t<li><a href=\"display.php?{$misc->href}&table=", urlencode($_REQUEST['table']), "&subject=table&return_url={$return_url}&return_desc=",
 			urlencode($lang['strback']), "\">{$lang['strbrowse']}</a></li>\n";
 		echo "\t<li><a href=\"tables.php?action=confselectrows&{$misc->href}&table=", urlencode($_REQUEST['table']),"\">{$lang['strselect']}</a></li>\n";
 		echo "\t<li><a href=\"tables.php?action=confinsertrow&{$misc->href}&table=", urlencode($_REQUEST['table']),"\">{$lang['strinsert']}</a></li>\n";
